==========
How to use
==========

Comming soon...

Generate reports
~~~~~~~~~~~~~~~~

Comming soon...

Main report
-----------

Comming soon...

Device report
-------------

Comming soon...

Costs & Extra costs
~~~~~~~~~~~~~~~~~~~

Comming soon...

Costs
-------------

Comming soon...

Extra costs
-------------

Comming soon...

Teams
~~~~~~~~~~~~~~~~

Comming soon...

Collects Data
~~~~~~~~~~~~~~~~

Comming soon...
